==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Specifies a set of Groups whose Users are to be included or excluded
 */
@ApiModel(description = "Specifies a set of Groups whose Users are to be included or excluded")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.JSON_PROPERTY_INCLUDE })
@JsonTypeName("AuthenticatorEnrollmentPolicyConditions_allOf_people_groups")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<String> include = null;

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups() {
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups include(List<String> include) {

        this.include = include;
        return this;
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups addincludeItem(String includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Groups to be included
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Groups to be included")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<String> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups authenticatorEnrollmentPolicyConditionsAllOfPeopleGroups = (AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups) o;
        return Objects.equals(this.include, authenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Specifies a set of Groups whose Users are to be included or excluded
 */
@ApiModel(description = "Specifies a set of Groups whose Users are to be included or excluded")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.JSON_PROPERTY_INCLUDE })
@JsonTypeName("AuthenticatorEnrollmentPolicyConditions_allOf_people_groups")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<String> include = null;

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups() {
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups include(List<String> include) {

        this.include = include;
        return this;
    }

    public AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups addincludeItem(String includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Groups to be included
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Groups to be included")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<String> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups authenticatorEnrollmentPolicyConditionsAllOfPeopleGroups = (AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups) o;
        return Objects.equals(this.include, authenticatorEnrollmentPolicyConditionsAllOfPeopleGroups.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyConditionsAllOfPeopleGroups {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
